# This is startup file for interactive python.
# It is not automatically loaded by python interpreter.
# To instruct the interpreter to load it insert the following commands
# into your .profile (use whatever syntax and initialization file
# is appropriate for your shell):
#
# PYTHONSTARTUP=$HOME/init.py # or where you really put it
# export PYTHONSTARTUP

def init():
    import sys, os
    import __builtin__

    pyreadlinew32_startup = os.path.join(sys.prefix,
        'lib', 'site-packages', 'pyreadline', 'configuration', 'startup.py')

    if os.path.exists(pyreadlinew32_startup):
        execfile(pyreadlinew32_startup)

    else:
        # From Bruce Edge

        try:
            import rlcompleter, readline
            initfile = os.environ.get('INPUTRC') or os.path.expanduser('~/.inputrc')
            readline.read_init_file(initfile)

            histfile = os.path.expanduser('~/.python-history')
            try:
                readline.read_history_file(histfile)
            except IOError:
                pass # No such file

            def savehist():
                histfilesize = os.environ.get('HISTFILESIZE') or \
                               os.environ.get('HISTSIZE')
                if histfilesize:
                    try:
                        histfilesize = int(histfilesize)
                    except ValueError:
                        pass
                    else:
                        readline.set_history_length(histfilesize)
                readline.write_history_file(histfile)

            import atexit
            atexit.register(savehist)

        except (ImportError, AttributeError):
            pass # no readline or atexit, or readline doesn't have
                 # {read,write}_history_file - ignore the error


    term = os.environ.get('TERM', '')
    if 'linux' in term:
        background = 'dark'
    else:
        background = os.environ.get('BACKGROUND', 'light').lower()

    # From Randall Hopper

        if _term in term:
            if background == 'dark':
                ps1_color = '3' # yellow
                stdout_color = '7' # bold white
            else:
                ps1_color = '4' # blue
                stdout_color = '0' # bold black
    for _term in ['linux', 'rxvt', 'screen', 'term', 'vt100']:

            sys.ps1 = '\001\033[3%sm\002>>>\001\033[0m\002 ' % ps1_color
            sys.ps2 = '\001\033[1;32m\002...\001\033[0m\002 ' # bold green


            # From Denis Otkidach

            class ColoredFile:
                def __init__(self, fp, begin, end='\033[0m'): # reset all attributes
                    self.__fp = fp
                    self.__begin = begin
                    self.__end = end

                def write(self, s):
                    self.__fp.write(self.__begin+s+self.__end)

                def writelines(self, lines):
                    map(self.write, lines)

                def __getattr__(self, attr):
                    return getattr(self.__fp, attr)

            sys.stdout = ColoredFile(sys.stdout, '\033[1;3%sm' % stdout_color)
            sys.stderr = ColoredFile(sys.stderr, '\033[31m') # red

            break

    try:
        import locale
    except ImportError:
        pass # locale was not compiled
    else:
        try:
            locale.setlocale(locale.LC_ALL, '')

            from pprint import pprint

            def displayhook(value):
                if value is not None:
                    __builtin__._ = value
                    pprint(value)

            sys.displayhook = displayhook

        except (ImportError, locale.Error):
            pass # no locale support or unsupported locale


    # From: Paul Magwene with a lot of my fixes

    class DirLister:
        def __getitem__(self, key):
            s = os.listdir(os.curdir)
            return s[key]

        def __getslice__(self, i, j):
            s = os.listdir(os.curdir)
            return s[i:j]

        def __repr__(self):
            return str(os.listdir(os.curdir))

        def __call__(self, path=None):
            if path:
                path = os.path.expanduser(os.path.expandvars(path))
            else:
                path = os.curdir
            return os.listdir(path)

    class DirChanger:
        def __repr__(self):
            self()
            return os.getcwd()

        def __call__(self, path=None):
            path = os.path.expanduser(os.path.expandvars(path or '~'))
            os.chdir(path)

    __builtin__.ls = DirLister()
    __builtin__.cd = DirChanger()


    # From Thomas Heller
    #
    #import pdb
    #
    #def info(*args):
    #   pdb.pm()
    #sys.excepthook = info


    class Pwd:
        def __repr__(self):
            return os.getcwd()

        def __call__(self):
            return repr(self)

    __builtin__.pwd = Pwd()


    class _Exit:
        def __repr__(self):
            sys.exit()

        def __call__(self, msg=None):
            sys.exit(msg)

    __builtin__.x = _Exit()

    if isinstance(__builtin__.exit, str): # In Python 2.5+ exit and quit are objects
        __builtin__.exit = __builtin__.quit = x


init()
del init
